﻿/**
 * @fileOverview パーカッションクラスを記述するファイルです。
 *
 * @author Naoki Yamada
 * @version 1.0.0
 */

/**
 * パーカッションのモデル名とメーカー名をセットします。
 *
 * @class パーカッションエンティティのクラスです。<br />
 * パーカッションのモデル名とメーカー名の情報を保有し、それらを取り扱う機能を保有します。
 *
 * @param {String} modelname モデル名
 * @param {String} vendor    メーカー名
 */
var Percussion = function(modelname, vendor) {

	/**
	 * モデル名
	 *
	 * @type String
	 * @return {String}
	 */
	this.modelname = modelname;

	/**
	 * メーカー名
	 *
	 * @type String
	 * @return {String}
	 */
	this.vendor = vendor;

	/**
	 * パーカッションを紹介する文章を作成します。<br />
	 * モデル名とメーカー名に愛称を付加して、紹介する文章を作成します。
	 *
	 * @param {String} nickname 愛称
	 * @return {String} 紹介文
	 *
	 * @example
	 * mainPercussion.introduceMyPercussion('要塞');
	 * 出力： 「私のパーカッションはTAMAのXXXというモデルで、要塞と呼んでいます。」
	 */
	this.introduceMyPercussion = function(nickname) {
		return '私のパーカッションは' + this.vendor + 'の' + this.modelname + 'というモデルで、' + nickname + 'と呼んでいます。';
	}

}