﻿/**
 * @fileOverview キーボードクラスを記述するファイルです。
 *
 * @author Naoki Yamada
 * @version 1.0.0
 */

/**
 * キーボードのモデル名とメーカー名をセットします。
 *
 * @class　キーボードエンティティのクラスです。<br />
 * キーボードのモデル名とメーカー名の情報を保有し、それらを取り扱う機能を保有します。
 *
 * @param {String} modelname モデル名
 * @param {String} vendor    メーカー名
 */
var Keyboard = function(modelname, vendor) {

	/**
	 * モデル名
	 *
	 * @returns {String}
	 */
	this.modelname = modelname;

	/**
	 * メーカー名
	 *
	 * @returns {String}
	 */
	this.vendor = vendor;

	/**
	 * キーボードを紹介する文章を作成します。<br />
	 * モデル名とメーカー名に愛称を付加して、紹介する文章を作成します。
	 *
	 * @param {String} nickname 愛称
	 * @return {String} 紹介文
	 *
	 * @example
	 * mainKeyboard.introduceMyKeyboard('よしえ');
	 * 出力： 「私のキーボードはYAMAHAのMOTIF XFというモデルで、よしえと呼んでいます。」
	 */
	this.introduceMyKeyboard = function(nickname) {
		return '私のキーボードは' + this.vendor + 'の' + this.modelname + 'というモデルで、' + nickname + 'と呼んでいます。';
	}

}